.. _release/migration:

***************
Migration notes
***************

This section will show more detailed information when relevant for switching to
a new version, such as when upgrading involves backwards incompatibilities.

.. _release/migration/1.0.0:

Migrate to 1.0.0
================

Dropped support for Python 2.x. The minimum supported version is now Python 3.7.
